Pedigrees (families and crosses)
================================

.. automodule:: anhima.ped
.. autofunction:: diploid_inheritance
.. autofunction:: diploid_mendelian_error
.. autofunction:: count_diploid_mendelian_error
